%% Duty Cycle--DAM
% This program is to generate representative daily duty cycles for testing 
% based on the probabilities of each type.
clear; clc;
load('PowerOutput.mat');
%{ 
Data: (La Jolla Node)
   PowerDA:    Include hourly power dispatch from 2013-2014 (17520 observations)
               with E/P ratio 1, 1.2, 3, 4, 6.86, 8.5; start with SOC = 0
   PowerDAREG: Regulation on top of day-ahead dispatch (Hourly) from 2013-2014
               with E/P ratio 1, 3, 4
   PowerRAMP:  Include 15-min power dispatch from 2013-2014 (70080 observations)
               with E/P ratio 1, 2, 3, 4
   PowerDCM:   Include 15-min POwer dispatch in 2014 (35040 observations)
               with E/P ratio 1, 3, 4
   PowerCR:    Hourly power dispatch for congestion relief application
               with E/P ratio 1, 2, 3, 4
 %}

%% 1. Produce the matrix of unique duty cycles with its probability
%{
For Cell level DAM testing and other applications, we find the week with 
most representative cycles based on the unique cycle matrix we produced here.
%}
Power = PowerDA_EP1;
%Power=PowerDCM_EP1;
numDay = 730;
%numDay=365;      % for DCM we have only one year

EtoP = 1; % E/P ratio

% Output DutyCycles: All types of unique cycle (each row)
% Output Frequency:  The frequency and probability related to each type
[DutyCycles,Frequency]=DutyCycleGenerator(Power,numDay,EtoP);


%% 3. Applications
% Select the most representative week
%{
Input:  Power- Original power output from all applications
        DutyCycles- All types of unique cycle from section 1
        numDay- number of days in the period
Output: DutyCycleCellProb- contains 104 rows, which is total of 104 weeks in 2 years
                           The number of columns is the number of unique
                           types from DutyCycles matrix
        PowerWeek - Reshape the power vector into weekly data (104x168)
%}
[DutyCycleProb,PowerWeek]=DutyCycleCellProb(Power,DutyCycles,numDay);


%% Pick the most representative week
% Select the week with higher probabilty in first few columns (DutyCycleProb)
PowerTest = PowerWeek(1,:)'





